@@ -7,9 +7,9 @@
  * This file is include by src/login.php, src/redirect.php and
  * src/load_prefs.php.
  *
- * @copyright &copy; 1999-2007 The SquirrelMail Project Team
+ * @copyright 1999-2010 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: constants.php 12932 2008-02-10 16:49:47Z kink $
+ * @version $Id: constants.php 13893 2010-01-25 02:47:41Z pdontthink $
  * @package squirrelmail
  * @since 1.2.0
  */
@@ -53,5 +53,12 @@ define('SMPREF_JS_OFF', 0);
 define('SMPREF_JS_ON', 1);
 define('SMPREF_JS_AUTODETECT', 2);
 
+/* Define constants for address book functionalities. */
+define('SM_ABOOK_FIELD_NICKNAME', 0);
+define('SM_ABOOK_FIELD_FIRSTNAME', 1);
+define('SM_ABOOK_FIELD_LASTNAME', 2);
+define('SM_ABOOK_FIELD_EMAIL', 3);
+define('SM_ABOOK_FIELD_LABEL', 4);
+
 do_hook('loading_constants');
 
