@@ -8,9 +8,9 @@
  * other PHP scripts? The only SM-specific thing is $sm_language, I think.
  *
  * @link http://www.php.net/gettext Original php gettext manual
- * @copyright &copy; 1999-2009 The SquirrelMail Project Team
+ * @copyright 1999-2010 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: gettext.php 13549 2009-04-15 22:00:49Z jervfors $
+ * @version $Id: gettext.php 13893 2010-01-25 02:47:41Z pdontthink $
  * @since 1.1.2
  * @package squirrelmail
  * @subpackage i18n
@@ -96,7 +96,7 @@ function gettext_php_load_strings() {
             $SkipRead = false;
         }
         
-        if (ereg('^msgid "(.*)"$', $line, $match)) {
+        if (preg_match('/^msgid "(.*)"$/', $line, $match)) {
             if ($match[1] == '') {
                 /*
                  * Potential multi-line
@@ -106,7 +106,7 @@ function gettext_php_load_strings() {
                  */
                 $key = '';
                 $line = trim(fgets($file, 4096));
-                while (ereg('^[ ]*"(.*)"[ ]*$', $line, $match)) {
+                while (preg_match('/^[ ]*"(.*)"[ ]*$/', $line, $match)) {
                     $key .= $match[1];
                     $line = trim(fgets($file, 4096));
                 }
@@ -115,7 +115,7 @@ function gettext_php_load_strings() {
                 /* msgid "string string" */
                 $key = $match[1];
             }
-        } elseif (ereg('^msgstr "(.*)"$', $line, $match)) {
+        } elseif (preg_match('/^msgstr "(.*)"$/', $line, $match)) {
             if ($match[1] == '') {
                 /*
                  * Potential multi-line
@@ -125,7 +125,7 @@ function gettext_php_load_strings() {
                  */
                 $gettext_php_translateStrings[$key] = '';
                 $line = trim(fgets($file, 4096));
-                while (ereg('^[ ]*"(.*)"[ ]*$', $line, $match)) {
+                while (preg_match('/^[ ]*"(.*)"[ ]*$/', $line, $match)) {
                     $gettext_php_translateStrings[$key] .= $match[1];
                     $line = trim(fgets($file, 4096));
                 }
