@@ -3,9 +3,9 @@
 /**
  * global.php
  *
- * @copyright &copy; 1999-2009 The SquirrelMail Project Team
+ * @copyright 1999-2010 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: global.php 13676 2009-05-11 22:48:03Z pdontthink $
+ * @version $Id: global.php 13896 2010-01-27 23:35:26Z pdontthink $
  * @package squirrelmail
  */
 
@@ -64,6 +64,16 @@ if ((bool) ini_get('register_globals') &&
     unset($GLOBALS['value']);
 }
 
+/**
+ * There are some PHP settings that SquirrelMail is incompatible with
+ * and cannot be changed by software at run-time; refuse to run if such
+ * settings are being used...
+ */
+$php_session_auto_start = ini_get('session.auto_start');
+if ((bool)$php_session_auto_start && $php_session_auto_start != 'off') {
+    die('SquirrelMail 1.4.x is not compatible with PHP\'s session.auto_start setting.  Please disable it at least for the location where SquirrelMail is installed.');
+}
+
 /**
  * Strip any tags added to the url from PHP_SELF.
  * This fixes hand crafted url XXS expoits for any
@@ -87,6 +97,12 @@ if (isset($_SERVER['PHP_SELF'])) {
 if (isset($_SERVER['QUERY_STRING'])) {
     $_SERVER['QUERY_STRING'] = htmlspecialchars($_SERVER['QUERY_STRING']);
 }
+/*
+ * same needed for REQUEST_URI because it's used in php_self()
+ */
+if (isset($_SERVER['REQUEST_URI'])) {
+    $_SERVER['REQUEST_URI'] = htmlspecialchars($_SERVER['REQUEST_URI']);
+}
 
 /**
  * Bring in the config file
@@ -267,7 +283,10 @@ function sqsession_unregister ($name) {
     sqsession_is_active();
 
     unset($_SESSION[$name]);
-    session_unregister($name);
+
+    // starts throwing warnings in PHP 5.3.0 and is
+    // removed in PHP 6 and is redundant anyway
+    //session_unregister($name);
 }
 
 /**
