@@ -11,9 +11,9 @@
  *    - Send mail
  *    - Save As Draft
  *
- * @copyright &copy; 1999-2009 The SquirrelMail Project Team
+ * @copyright 1999-2010 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: compose.php 13695 2009-05-14 06:26:29Z pdontthink $
+ * @version $Id: compose.php 13915 2010-02-16 20:17:13Z pdontthink $
  * @package squirrelmail
  */
 
@@ -67,6 +67,9 @@ if (isset($send) && $send) {
     $SQ_GLOBAL = SQ_FORM;
 }
 sqgetGlobalVar('smaction',$action, $SQ_GLOBAL);
+if (!sqgetGlobalVar('smtoken',$submitted_token, $SQ_GLOBAL)) {
+    $submitted_token = '';
+}
 sqgetGlobalVar('session',$session, $SQ_GLOBAL);
 sqgetGlobalVar('mailbox',$mailbox, $SQ_GLOBAL);
 if ( !sqgetGlobalVar('identity',$identity, $SQ_GLOBAL) ) {
@@ -377,6 +380,11 @@ if (!isset($mailbox) || $mailbox == '' || ($mailbox == 'None')) {
 }
 
 if ($draft) {
+
+    // validate security token
+    //
+    sm_validate_security_token($submitted_token, 3600, TRUE);
+
     /*
      * Set $default_charset to correspond with the user's selection
      * of language interface.
@@ -391,11 +399,11 @@ if ($draft) {
         if(isset($delete_draft)) {
             if ( !isset($pageheader_sent) || !$pageheader_sent ) {
                 Header("Location: $location/delete_message.php?mailbox=" . urlencode($draft_folder) .
-                        "&message=$delete_draft&sort=$sort&startMessage=1&saved_draft=yes");
+                        "&message=$delete_draft&sort=$sort&startMessage=1&saved_draft=yes&smtoken=" . sm_generate_security_token());
             } else {
                 echo '   <br><br><center><a href="' . $location
                     . "/delete_message.php?mailbox=" . urlencode($draft_folder)
-                    . "&message=$delete_draft&sort=$sort&startMessage=1&saved_draft=yes\">"
+                    . "&message=$delete_draft&sort=$sort&startMessage=1&saved_draft=yes&smtoken=" . sm_generate_security_token() . "\">"
                     . _("Return") . '</a></center>';
             }
             exit();
@@ -428,6 +436,11 @@ if ($draft) {
 }
 
 if ($send) {
+
+    // validate security token
+    //
+    sm_validate_security_token($submitted_token, 3600, TRUE);
+
     if (isset($_FILES['attachfile']) &&
             $_FILES['attachfile']['tmp_name'] &&
             $_FILES['attachfile']['tmp_name'] != 'none') {
@@ -486,7 +499,7 @@ if ($send) {
         /* if it is resumed draft, delete draft message */
         if ( isset($delete_draft)) {
             Header("Location: $location/delete_message.php?mailbox=" . urlencode( $draft_folder ).
-                    "&message=$delete_draft&sort=$sort&startMessage=1&mail_sent=yes");
+                    "&message=$delete_draft&sort=$sort&startMessage=1&mail_sent=yes&smtoken=" . sm_generate_security_token());
             exit();
         }
         if ($compose_new_win == '1') {
@@ -513,6 +526,11 @@ if ($send) {
         /* sqimap_logout($imapConnection); */
     }
 } elseif (isset($html_addr_search_done)) {
+
+    // validate security token
+    //
+    sm_validate_security_token($submitted_token, 3600, TRUE);
+
     if ($compose_new_win == '1') {
         compose_Header($color, $mailbox);
     }
@@ -557,6 +575,11 @@ if ($send) {
      */
     include_once('./addrbook_search_html.php');
 } elseif (isset($attach)) {
+
+    // validate security token
+    //
+    sm_validate_security_token($submitted_token, 3600, TRUE);
+
     if (saveAttachedFiles($session)) {
         plain_error_message(_("Could not move/copy file. File not attached"), $color);
     }
@@ -568,6 +591,11 @@ if ($send) {
     showInputForm($session);
 }
 elseif (isset($sigappend)) {
+
+    // validate security token
+    //
+    sm_validate_security_token($submitted_token, 3600, TRUE);
+
     $signature = $idents[$identity]['signature'];
     
     $body .= "\n\n".($prefix_sig==true? "-- \n":'').$signature;
@@ -578,6 +606,11 @@ elseif (isset($sigappend)) {
     }
     showInputForm($session);
 } elseif (isset($do_delete)) {
+
+    // validate security token
+    //
+    sm_validate_security_token($submitted_token, 3600, TRUE);
+
     if ($compose_new_win == '1') {
         compose_Header($color, $mailbox);
     } else {
@@ -655,7 +688,7 @@ function newMail ($mailbox='', $passed_id='', $passed_ent_id='', $action='', $se
     global $editor_size, $default_use_priority, $body, $idents,
         $use_signature, $composesession, $data_dir, $username,
         $username, $key, $imapServerAddress, $imapPort, 
-        $composeMessage, $body_quote;
+        $composeMessage, $body_quote, $strip_sigs;
     global $languages, $squirrelmail_language, $default_charset;
 
     /*
@@ -793,7 +826,7 @@ function newMail ($mailbox='', $passed_id='', $passed_ent_id='', $action='', $se
                 $cnt = count($body_ary) ;
                 $body = '';
                 for ($i=0; $i < $cnt; $i++) {
-                    if (!ereg("^[>\\s]*$", $body_ary[$i])  || !$body_ary[$i]) {
+                    if (!preg_match('/^[>\s]*$/', $body_ary[$i])  || !$body_ary[$i]) {
                         sqWordWrap($body_ary[$i], $editor_size, $default_charset );
                         $body .= $body_ary[$i] . "\n";
                     }
@@ -859,6 +892,9 @@ function newMail ($mailbox='', $passed_id='', $passed_ent_id='', $action='', $se
                 $body = '';
                 $cnt = count($rewrap_body);
                 for ($i=0;$i<$cnt;$i++) {
+                    if ($strip_sigs && $rewrap_body[$i] == '-- ') {
+                        break;
+                    }
                     sqWordWrap($rewrap_body[$i], $editor_size, $default_charset);
                     if (preg_match("/^(>+)/", $rewrap_body[$i], $matches)) {
                         $gt = $matches[1];
@@ -1032,6 +1068,7 @@ function showInputForm ($session, $values=false) {
 
     echo ">\n";
 
+    echo addHidden('smtoken', sm_generate_security_token());
     echo addHidden('startMessage', $startMessage);
 
     if ($action == 'draft') {
@@ -1473,7 +1510,7 @@ function deliverMessage(&$composeMessage, $draft=false) {
     }
     $composeMessage->setBody($body);
 
-    if (ereg("^([^@%/]+)[@%/](.+)$", $username, $usernamedata)) {
+    if (preg_match('|^([^@%/]+)[@%/](.+)$|', $username, $usernamedata)) {
         $popuser = $usernamedata[1];
         $domain  = $usernamedata[2];
         unset($usernamedata);
@@ -1491,7 +1528,7 @@ function deliverMessage(&$composeMessage, $draft=false) {
     if (!$rfc822_header->from[0]->host) $rfc822_header->from[0]->host = $domain;
     if ($full_name) {
         $from = $rfc822_header->from[0];
-        $full_name_encoded = encodeHeader($full_name);
+        $full_name_encoded = encodeHeader('"' . $full_name . '"');
         if ($full_name_encoded != $full_name) {
             $from_addr = $full_name_encoded .' <'.$from->mailbox.'@'.$from->host.'>';
         } else {
