@@ -3,9 +3,9 @@
 /**
  * SquirrelMail configtest script
  *
- * @copyright &copy; 2003-2007 The SquirrelMail Project Team
+ * @copyright 2003-2010 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: configtest.php 12988 2008-03-03 14:06:36Z kink $
+ * @version $Id: configtest.php 13893 2010-01-25 02:47:41Z pdontthink $
  * @package squirrelmail
  * @subpackage config
  */
@@ -92,6 +92,15 @@ echo $IND . 'display_errors: ' . ini_get('display_errors') . "<br />\n";
 
 echo $IND . 'error_reporting: ' . ini_get('error_reporting') . "<br />\n";
 
+if ((bool) ini_get('session.auto_start') && ini_get('session.auto_start') != 'off') {
+    $msg = 'session.auto_start is turned on in your PHP configuration, but SquirrelMail'
+         . ' 1.4.x will not work with it (otherwise valid logins will usually'
+         . ' result in "You must be logged in to access this page" errors).'
+         . ' You can disable session.auto_start only in the squirrelmail directory' 
+         . ' if you need to leave it turned on for other applications.';
+    do_err($msg, true);
+}
+
 $safe_mode = ini_get('safe_mode');
 if ($safe_mode) {
     echo $IND . 'safe_mode: ' . $safe_mode;
@@ -368,15 +377,16 @@ if($useSendmail) {
 
     /* POP before SMTP */
     if($pop_before_smtp) {
-        $stream = fsockopen($smtpServerAddress, 110, $err_no, $err_str);
+        if (empty($pop_before_smtp_host)) $pop_before_smtp_host = $smtpServerAddress;
+        $stream = fsockopen($pop_before_smtp_host, 110, $err_no, $err_str);
         if (!$stream) {
-            do_err("Error connecting to POP Server ($smtpServerAddress:110) "
+            do_err("Error connecting to POP Server ($pop_before_smtp_host:110) "
                 . $err_no . ' : ' . htmlspecialchars($err_str));
         }
 
         $tmp = fgets($stream, 1024);
         if (substr($tmp, 0, 3) != '+OK') {
-            do_err("Error connecting to POP Server ($smtpServerAddress:110)"
+            do_err("Error connecting to POP Server ($pop_before_smtp_host:110)"
                 . ' '.htmlspecialchars($tmp));
         }
         fputs($stream, 'QUIT');
