@@ -6,9 +6,9 @@
  * Does the actual renaming of files on the IMAP server.
  * Called from the folders.php
  *
- * @copyright &copy; 1999-2009 The SquirrelMail Project Team
+ * @copyright 1999-2010 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: folders_rename_do.php 13549 2009-04-15 22:00:49Z jervfors $
+ * @version $Id: folders_rename_do.php 13893 2010-01-25 02:47:41Z pdontthink $
  * @package squirrelmail
  */
 
@@ -35,8 +35,14 @@ sqgetGlobalVar('onetimepad',$onetimepad,    SQ_SESSION);
 sqgetGlobalVar('orig',      $orig,          SQ_POST);
 sqgetGlobalVar('old_name',  $old_name,      SQ_POST);
 sqgetGlobalVar('new_name',  $new_name,      SQ_POST);
+if (!sqgetGlobalVar('smtoken',$submitted_token, SQ_POST)) {
+    $submitted_token = '';
+}
 /* end globals */
 
+// first, validate security token
+sm_validate_security_token($submitted_token, 3600, TRUE);
+
 $new_name = trim($new_name);
 
 if (substr_count($new_name, '"') || substr_count($new_name, "\\") ||
