@@ -6,9 +6,9 @@
  * This is the code for the left bar. The left bar shows the folders
  * available, and has cookie information.
  *
- * @copyright &copy; 1999-2007 The SquirrelMail Project Team
+ * @copyright 1999-2010 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: left_main.php 13243 2008-07-20 21:17:38Z pdontthink $
+ * @version $Id: left_main.php 13893 2010-01-25 02:47:41Z pdontthink $
  * @package squirrelmail
  */
 
@@ -46,7 +46,7 @@ function formatMailboxName($imapConnection, $box_array) {
     $mailboxURL = urlencode($real_box);
 
     /* Strip down the mailbox name. */
-    if (ereg("^( *)([^ ]*)$", $mailbox, $regs)) {
+    if (preg_match('/^( *)([^ ]*)$/', $mailbox, $regs)) {
         $mailbox = $regs[2];
     }
     $unseen = 0;
@@ -450,7 +450,7 @@ for ($i = 0; $i < count($boxes); $i++) {
             } else {
                 $line .= "<font color=\"$color[15]\">";
             }
-            if (ereg("^( *)([^ ]*)", $mailbox, $regs)) {
+            if (preg_match('/^( *)([^ ]*)/', $mailbox, $regs)) {
                 $mailbox = str_replace('&nbsp;','',$mailbox);
                 $line .= str_replace(' ', '&nbsp;', $mailbox);
             }
