@@ -6,9 +6,9 @@
  * This is where the mailboxes are listed. This controls most of what
  * goes on in SquirrelMail.
  *
- * @copyright &copy; 1999-2009 The SquirrelMail Project Team
+ * @copyright 1999-2010 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: right_main.php 13549 2009-04-15 22:00:49Z jervfors $
+ * @version $Id: right_main.php 13905 2010-02-13 22:49:58Z pdontthink $
  * @package squirrelmail
  */
 
@@ -152,6 +152,13 @@ else {
 
 sqimap_mailbox_select($imapConnection, $mailbox);
 
+// the preg_match() is a fix for Dovecot wherein UIDs can be bigger than
+// normal integers - this isn't in 1.4 yet, but when adding new code, why not...
+if (sqgetGlobalVar('unread_passed_id', $unread_passed_id, SQ_GET)
+ && preg_match('/^[0-9]+$/', $unread_passed_id)) {
+    sqimap_toggle_flag($imapConnection, $unread_passed_id, '\\Seen', false, true);
+}
+
 if ($composenew) {
     $comp_uri = SM_PATH . 'src/compose.php?mailbox='. urlencode($mailbox).
         "&session=" .urlencode($session);
